Crate astrid_daemon

Crate astrid_daemon 

Astrid Daemon — shared library for the background kernel process.

This crate provides the daemon entry point as a library function so it can be reused by both the standalone astrid-daemon binary and the astrid CLI binary (which ships both via cargo install astrid).

Structs

Args
Astrid Daemon - Background kernel process

Functions

run
Run the Astrid daemon with the given arguments.